@@ -65,7 +65,7 @@ def mysql_connect(url=None, autocommit=True):
     conf = MySQLConfig(url)
 
     client = pymysql.Connect(
-        host=conf.host, port=conf.port, database=conf.database, user=conf.user, password=conf.password)
+        host=conf.host, port=conf.port, database=conf.database, user=conf.user, password=conf.password, connect_timeout=3600)
     client.autocommit(autocommit)
     return client
 
